"use strict";

const panther = require("panther-engine");
const config = require("./config");

const availableCommands = ["build", "deploy", "serve", "launch", "test-sass"];

// Determine which CLI command was run and perform the appropriate action

if (process.argv) {
  const args = process.argv.slice(2);
  if (!args[0] || !availableCommands.includes(args[0])) {
    process.exit();
  }
  if (args[0] === "deploy") {
    // Modify some of the Panther Engine configuration settings when
    // doing a production build of the pattern library website
    config.isDev = false;
    config.basePath = "/ux-pattern-library";
  }
  panther.init(config);

  switch (args[0]) {
    case "build":
    case "deploy":
      panther.build();
      break;
    case "serve":
      panther.serve();
      break;
    case "launch":
      panther.launch();
      break;
    case "test-sass":
      panther.testSASS()
        .then(() => {
          process.exit(0);
        })
        .catch(() => {
          process.exit(1);
        });
      break;
  }
}
