/**
 * commonly used DOM methods
 */

/**
 * @method focusElementInPanel
 * @description focuses element by selector and returns true if element is visible
 * @param {HTMlElement} focusElement
 * @return {boolean}
 */
export function focusElementInPanel(focusElement) {
  focusElement.focus();

  // if element is hidden offsetHeight would be 0
  return focusElement.offsetHeight !== 0;
}

/**
 * @method toArray
 * @description converts and array like (nodelist) to an array
 * @param val {Array|NodeList}
 * @return {Array}
 */
export function toArray(val) {
  if (typeof val === "undefined") {
    return null;
  } else if (typeof Array.from !== "undefined") {
    return Array.from(val);
  } else {
    return [].slice.call(val);
  }
}

/**
 * @method ariaToggle
 * @description will toggle aria expanded attribute on all matching elements
 * @param {string} selector
 * @param {string} ariaLabel
 * @param {boolean} value
 * @return {void}
 */
export function ariaToggle(selector, ariaLabel, value) {
  const targetButtons = toArray(document.querySelectorAll(selector));

  targetButtons.forEach((m) => {
    const ariaExpandedValue = typeof value !== "undefined" ? value : false;
    m.setAttribute("aria-expanded", ariaExpandedValue);

    if (ariaLabel) {
      const buttonText = m.querySelector(".c-control__button-text");
      buttonText.innerText = ariaLabel;
    }
  });
}
